@@ -51,6 +51,11 @@ insert into cth values(DEFAULT,'test2','02 March 2003','temperature','53');
 insert into cth values(DEFAULT,'test2','02 March 2003','test_result','FAIL');
 insert into cth values(DEFAULT,'test2','02 March 2003','test_startdate','01 March 2003');
 insert into cth values(DEFAULT,'test2','02 March 2003','volts','3.1234');
+-- next group tests for NULL rowids
+insert into cth values(DEFAULT,NULL,'25 October 2007','temperature','57');
+insert into cth values(DEFAULT,NULL,'25 October 2007','test_result','PASS');
+insert into cth values(DEFAULT,NULL,'25 October 2007','test_startdate','24 October 2007');
+insert into cth values(DEFAULT,NULL,'25 October 2007','volts','1.41234');
 
 -- return attributes as plain text
 SELECT * FROM crosstab(
@@ -88,6 +93,17 @@ SELECT * FROM crosstab(
   'SELECT DISTINCT rowdt, attribute FROM cth ORDER BY 2')
 AS c(rowid text, rowdt timestamp, temperature int4, test_result text, test_startdate timestamp, volts float8);
 
+-- if source query returns zero rows, get zero rows returned
+SELECT * FROM crosstab(
+  'SELECT rowid, rowdt, attribute, val FROM cth WHERE false ORDER BY 1',
+  'SELECT DISTINCT attribute FROM cth ORDER BY 1')
+AS c(rowid text, rowdt timestamp, temperature text, test_result text, test_startdate text, volts text);
+
+-- if source query returns zero rows, get zero rows returned even if category query generates no rows
+SELECT * FROM crosstab(
+  'SELECT rowid, rowdt, attribute, val FROM cth WHERE false ORDER BY 1',
+  'SELECT DISTINCT attribute FROM cth WHERE false ORDER BY 1')
+AS c(rowid text, rowdt timestamp, temperature text, test_result text, test_startdate text, volts text);
 
 --
 -- connectby
