@@ -2,7 +2,7 @@
 -- INTERVAL
 --
 
-SET DATESTYLE = DEFAULT;
+SET DATESTYLE = 'ISO';
 
 -- check acceptance of "time zone style"
 SELECT INTERVAL '01:00' AS "One hour";
@@ -66,3 +66,10 @@ SELECT '' AS ten, INTERVAL_TBL.*;
 -- updating pg_aggregate.agginitval
 
 select avg(f1) from interval_tbl;
+
+-- test long interval input
+select '4 millenniums 5 centuries 4 decades 1 year 4 months 4 days 17 minutes 31 seconds'::interval;
+
+-- check that '30 days' equals '1 month' according to the hash function
+select '30 days'::interval = '1 month'::interval as t;
+select interval_hash('30 days'::interval) = interval_hash('1 month'::interval) as t;
